@@ -1,6 +1,11 @@
 use crate::model::Geometry;
 
+pub fn with_quota(quota: f32, size: u32) -> u32 {
+    (size as f32 * quota) as u32
+}
+
 pub fn geometries_bsp(
+    quota: f32,
     i: usize,
     window_count: usize,
     left: u32,
@@ -14,25 +19,29 @@ pub fn geometries_bsp(
     } else if window_count == 1 {
         vec![Geometry(left, top, width, height)]
     } else if i % 2 == vertical {
-        let mut res = vec![Geometry(left, top, width, height / 2)];
+        let quota_height = with_quota(quota, height);
+        let mut res = vec![Geometry(left, top, width, quota_height)];
         res.append(&mut geometries_bsp(
+            quota,
             i + 1,
             window_count - 1,
             left,
-            top + height / 2,
+            top + quota_height,
             width,
-            height / 2,
+            height - quota_height,
             vertical,
         ));
         res
     } else {
-        let mut res = vec![Geometry(left, top, width / 2, height)];
+        let quota_width = with_quota(quota, width);
+        let mut res = vec![Geometry(left, top, quota_width, height)];
         res.append(&mut geometries_bsp(
+            quota,
             i + 1,
             window_count - 1,
-            left + width / 2,
+            left + quota_width,
             top,
-            width / 2,
+            width - quota_width,
             height,
             vertical,
         ));
