@@ -50,9 +50,9 @@ impl UmberWm {
             0
         };
         let geos = match workspace.layout {
-            Layout::Bspv => geometries_bsp(0, count, left, top, width, height, 1),
-            Layout::Bsph => geometries_bsp(0, count, left, top, width, height, 0),
-            Layout::Monocle => geometries_bsp(0, 1, left, top, width, height, 1),
+            Layout::Bspv => geometries_bsp(workspace.quota, 0, count, left, top, width, height, 1),
+            Layout::Bsph => geometries_bsp(workspace.quota, 0, count, left, top, width, height, 0),
+            Layout::Monocle => geometries_bsp(workspace.quota, 0, 1, left, top, width, height, 1),
         };
         match workspace.layout {
             Layout::Bspv | Layout::Bsph => resize_bsp(
@@ -270,11 +270,6 @@ impl UmberWm {
                     .windows
                     .get(workspace.focus)
                     .ok_or(Error::WindowNotFound)?);
-                let window_string = window.to_string();
-                self.run_command_callback(
-                    Events::OnCloseWindow,
-                    vec![("%window_id%".to_string(), window_string)],
-                );
                 let wm_delete_window = xcb::intern_atom(&self.conn, false, "WM_DELETE_WINDOW")
                     .get_reply()?
                     .atom();
@@ -305,6 +300,16 @@ impl UmberWm {
                     );
                 }
             }
+            Actions::DecreaseQuota => {
+                if workspace.quota > 0.1 {
+                    workspace.quota -= 0.1
+                }
+            }
+            Actions::IncreaseQuota => {
+                if workspace.quota < 0.9 {
+                    workspace.quota += 0.1
+                }
+            }
             Actions::ChangeLayout => {
                 workspace.layout = match workspace.layout {
                     Layout::Bspv => Layout::Monocle,
@@ -352,6 +357,11 @@ impl UmberWm {
                 }
             }
         }
+        let window_string = window.to_string();
+        self.run_command_callback(
+            Events::OnSetupWindow,
+            vec![("%window_id%".to_string(), window_string)],
+        );
         let wm_class =
             get_str_property(&self.conn, window, "WM_CLASS").ok_or(Error::FailedToGetWmClass)?;
         let window_type = get_atom_property(&self.conn, window, "_NET_WM_WINDOW_TYPE")?;
@@ -558,6 +568,11 @@ impl UmberWm {
                 }
                 if r == xcb::DESTROY_NOTIFY as u8 {
                     let map_notify: &xcb::DestroyNotifyEvent = unsafe { xcb::cast_event(&event) };
+                    let window_string = map_notify.window().to_string();
+                    self.run_command_callback(
+                        Events::OnCloseWindow,
+                        vec![("%window_id%".to_string(), window_string)],
+                    );
                     self.destroy_window(map_notify.window());
                 } else if r == xcb::BUTTON_PRESS as u8 {
                     let event: &xcb::ButtonPressEvent = unsafe { xcb::cast_event(&event) };
